@@ -60,6 +60,7 @@ class FFMPEG_VideoWriter:
         
     def close(self):
         self.proc.stdin.close()
+        self.proc.wait()
         del self.proc
         
 def ffmpeg_write(clip, filename, fps, codec="libx264", bitrate=None,
@@ -76,7 +77,7 @@ def ffmpeg_write(clip, filename, fps, codec="libx264", bitrate=None,
     writer = FFMPEG_VideoWriter(filename, clip.size, fps, codec = codec,
              bitrate=bitrate)
     i=0
-    nframes = clip.duration*fps
+    nframes = int(clip.duration*fps)
     
     while (i < nframes):
         frame = clip.get_frame(1.0*i/fps)
@@ -88,12 +89,21 @@ def ffmpeg_write(clip, filename, fps, codec="libx264", bitrate=None,
         if  ((i+1) % (nframes/10)) == 0:
             verbose_print("=")
         i += 1
+    
     writer.close()
     verbose_print("video done !")
         
         
 def write_image(filename, image):
-    pix_fmt = "rgba" if (image.shape[2] == 4) else "rgb24"
-    vf = FFMPEG_VideoWriter(filename, pix_fmt='rgba')
-    vf.writer_frame(image)
-    vf.close()
+    """ Writes an image (HxWx3 or HxWx4 numpy array) to a file, using
+        ffmpeg. """
+    proc = sp.Popen([ "ffmpeg", '-y',
+            '-s', "%dx%d"%(image.shape[:2][::-1]),
+            "-f", 'rawvideo',
+            '-pix_fmt', "rgba" if (image.shape[2] == 4) else "rgb24",
+            '-i','-', filename],
+            stdin=sp.PIPE, stdout=sp.PIPE, stderr=sp.PIPE)
+    image.tofile(proc.stdin)
+    proc.stdin.close()
+    proc.wait()
+    del proc
